# agnpy
Modelling Active Galactic Nuclei radiative processes with python.

## descritpion
`agnpy` focuses on the numerical computation of the photon spectra produced by leptonic radiative processes in jetted Active Galactic Nuclei (AGN).  

## documentation and quickstart
You are invited to check the documentation at https://agnpy.readthedocs.io/en/latest/.    
To get familiar with the code you can run the notebooks in `tutorials`.

## dependencies
The only dependencies are:

* [numpy](https://numpy.org) managing the numerical computation;

* [astropy](https://www.astropy.org) managing physical units and astronomical distances.

Additionally [matplotlib](https://matplotlib.org) is necessary to reproduce the examples in the documentation and in the `tutorials` notebooks.

## installation
The code is available in the [python package index](https://pypi.org/project/agnpy/) and can be installed via `pip`

```bash
pip install agnpy
```